/* Generated by wayland-scanner 1.18.0 */

#ifndef AGL_SHELL_SERVER_PROTOCOL_H
#define AGL_SHELL_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_agl_shell The agl_shell protocol
 * @section page_ifaces_agl_shell Interfaces
 * - @subpage page_iface_agl_shell - user interface for weston-ivi
 * @section page_copyright_agl_shell Copyright
 * <pre>
 *
 * Copyright © 2019 Collabora, Ltd.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * </pre>
 */
struct agl_shell;
struct wl_output;
struct wl_surface;

/**
 * @page page_iface_agl_shell agl_shell
 * @section page_iface_agl_shell_desc Description
 *
 * @section page_iface_agl_shell_api API
 * See @ref iface_agl_shell.
 */
/**
 * @defgroup iface_agl_shell The agl_shell interface
 *
 */
extern const struct wl_interface agl_shell_interface;

#ifndef AGL_SHELL_ERROR_ENUM
#define AGL_SHELL_ERROR_ENUM
enum agl_shell_error {
	AGL_SHELL_ERROR_INVALID_ARGUMENT = 0,
	AGL_SHELL_ERROR_BACKGROUND_EXISTS = 1,
	AGL_SHELL_ERROR_PANEL_EXISTS = 2,
};
#endif /* AGL_SHELL_ERROR_ENUM */

#ifndef AGL_SHELL_EDGE_ENUM
#define AGL_SHELL_EDGE_ENUM
enum agl_shell_edge {
	AGL_SHELL_EDGE_TOP = 0,
	AGL_SHELL_EDGE_BOTTOM = 1,
	AGL_SHELL_EDGE_LEFT = 2,
	AGL_SHELL_EDGE_RIGHT = 3,
};
#endif /* AGL_SHELL_EDGE_ENUM */

/**
 * @ingroup iface_agl_shell
 * @struct agl_shell_interface
 */
struct agl_shell_interface {
	/**
	 * client is ready to be shown
	 *
	 * Tell the server that this client is ready to be shown. The
	 * server will delay presentation during start-up until all shell
	 * clients are ready to be shown, and will display a black screen
	 * instead. This gives the client an oppurtunity to set up and
	 * configure several surfaces into a coherent interface.
	 *
	 * The client that binds to this interface must send this request,
	 * otherwise they may stall the compositor unnecessarily.
	 *
	 * If this request is called after the compositor has already
	 * finished start-up, no operation is performed.
	 */
	void (*ready)(struct wl_client *client,
		      struct wl_resource *resource);
	/**
	 * set surface as output's background
	 *
	 * Set the surface to act as the background of an output. After
	 * this request, the server will immediately send a configure event
	 * with the dimensions the client should use to cover the entire
	 * output.
	 *
	 * The surface must have a "desktop" surface role, as supported by
	 * libweston-desktop.
	 *
	 * Only a single surface may be the background for any output. If a
	 * background surface already exists, a protocol error is raised.
	 */
	void (*set_background)(struct wl_client *client,
			       struct wl_resource *resource,
			       struct wl_resource *surface,
			       struct wl_resource *output);
	/**
	 * set surface as panel
	 *
	 * Set the surface to act as a panel of an output. The 'edge'
	 * argument says what edge of the output the surface will be
	 * anchored to. After this request, the server will send a
	 * configure event with the correponding width/height that the
	 * client should use, and 0 for the other dimension. E.g. if the
	 * edge is 'top', the width will be the output's width, and the
	 * height will be 0.
	 *
	 * The surface must have a "desktop" surface role, as supported by
	 * libweston-desktop.
	 *
	 * The compositor will take the panel's window geometry into
	 * account when positioning other windows, so the panels are not
	 * covered.
	 *
	 * XXX: What happens if e.g. both top and left are used at the same
	 * time? Who gets to have the corner?
	 *
	 * Only a single surface may be the panel for an output's edge. If
	 * a surface already exists on an edge, a protocol error is raised.
	 */
	void (*set_panel)(struct wl_client *client,
			  struct wl_resource *resource,
			  struct wl_resource *surface,
			  struct wl_resource *output,
			  uint32_t edge);
	/**
	 * make client current window
	 *
	 * Ask the compositor to make a toplevel to become the
	 * current/focused window for window management purposes.
	 *
	 * See xdg_toplevel.set_app_id from the xdg-shell protocol for a
	 * description of app_id.
	 *
	 * If multiple toplevels have the same app_id, the result is
	 * unspecified.
	 *
	 * XXX: Do we need feedback to say it didn't work? (e.g. client
	 * does not exist)
	 */
	void (*activate_app)(struct wl_client *client,
			     struct wl_resource *resource,
			     const char *app_id,
			     struct wl_resource *output);
};


/**
 * @ingroup iface_agl_shell
 */
#define AGL_SHELL_READY_SINCE_VERSION 1
/**
 * @ingroup iface_agl_shell
 */
#define AGL_SHELL_SET_BACKGROUND_SINCE_VERSION 1
/**
 * @ingroup iface_agl_shell
 */
#define AGL_SHELL_SET_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_agl_shell
 */
#define AGL_SHELL_ACTIVATE_APP_SINCE_VERSION 1

#ifdef  __cplusplus
}
#endif

#endif
